@@ -4,7 +4,7 @@
 #define vtkOptions_h
 
 /* Whether vtkIdType is a 64-bit integer type (or a 32-bit integer type).  */
-/* #undef VTK_USE_64BIT_IDS */
+#define VTK_USE_64BIT_IDS
 
 /* Whether MTime should use a 64-bit integer type on 32 bit builds.  */
 /* #undef VTK_USE_64BIT_TIMESTAMPS */
